% Depth profile 10Be/26Al exposure age calculator calculating the best fit erosion rate E and
% exposure duration T within the range Emin-Emax/Tmin-Tmax (one period of exposure with constant
% erosion rate). The calculation is done using the expage calculator production rates (nuclide-
% specific LSD scaling) and assuming one period of exposure. At least two concentrations must be
% given for the calculator to work.
% Jakob Heyman - 2017

clear all;

tic();

% What version is this?
ver = '201702';

% input data----------------------------------------------------------------------------------------
% lat long alt shielding rho samplingyr
lat = -47.26627;
long = -70.96320;
elv = 583;
shield = 1;
rho = 2.4;
samplingyr = 2007;

% age and erosion ranges to test
Tmin = 200000; % yr
Tmax = 1000000; % yr
Emin = 0; % mm/ka
Emax = 3; % mm/ka

% number of E and T points for the 
ETgrid = 100;

% sample names - not really necessary but included anyway...
names = ['BC07-48a';'IBC07-48b';'IBC07-48c';'BC07-48d';'BC07-48e';'BC07-48f';'BC07-48g';'BC07-48h'];

% sample depths (cm)
dv = [10 20 30 40 50 75 100 150];

% sample 10Be conc and unc
N10 = [1508000 1242000 1153000 948000 802000 563000 381000 184000];
delN10 = [47000 39000 33000 29000 23000 18000 10000 6000];

% 10Be standard - can be a vector for different standards but it MUST be in column format!
std10 = ['07KNSTD'];

% sample 26Al conc and unc
N26 = [0];
delN26 = [0];

% 26Al standard - can be a vector for different standards but it MUST be in column format!
std26 = ['0'];
% end of input--------------------------------------------------------------------------------------

% make columns of input given in rows
if isrow(dv); dv = dv'; end;
if isrow(N10); N10 = N10'; end;
if isrow(delN10); delN10 = delN10'; end;
if isrow(N26); N26 = N26'; end;
if isrow(delN26); delN26 = delN26'; end;

% run and load al_be constants
make_al_be_consts;
load al_be_consts;

% run and load consts_LSD
make_consts_LSD;
load consts_LSD;

% Set nucl to 0 for both 10/26
nucl10 = 0; nucl26 = 0;

% Check and count if 10Be and 26Al is measured
n10 = sum(N10+delN10 > 0);
n26 = sum(N26+delN26 > 0);
if n10>1; nucl10 = 1; end;
if n26>1; nucl26 = 1; end;
if n10 < numel(dv);
	N10(n10+1:numel(dv),1) = 0;
	delN10(n10+1:numel(dv),1) = 0;
end;
if n26 < numel(dv);
	N26(n26+1:numel(dv),1) = 0;
	delN26(n26+1:numel(dv),1) = 0;
end;

% convert concentrations according to standards
if nucl10 == 1;
	for i = 1:size(std10,1);
		mult10(i,1) = al_be_consts.be_stds_cfs(strmatch(std10(i,:),al_be_consts.be_stds_names,'exact'));
	end;
	N10 = N10 .* mult10;
	delN10 = delN10 .* mult10;
end;
if nucl26 == 1;
	for i = 1:size(std26,1);
		mult26(i,1) = al_be_consts.al_stds_cfs(strmatch(std26(i,:),al_be_consts.al_stds_names,'exact'));
	end;
	N26 = N26 .* mult26;
	delN26 = delN26 .* mult26;
end;

% Define sample site atmospheric pressure
atm = ERA40atm(lat,long,elv);

% Pref
Pref10 = al_be_consts.P10_ref_nu; delPref10 = al_be_consts.delP10_ref_nu;
Pref26 = al_be_consts.P26_ref_nu; delPref26 = al_be_consts.delP26_ref_nu;
% Decay constant
l10 = al_be_consts.l10; dell10 = al_be_consts.dell10;
l26 = al_be_consts.l26; dell26 = al_be_consts.dell26;

% mesh for plotting
xx = linspace(Emin,Emax,1000);
yy = linspace(Tmin,Tmax,1000)';

% Vectors for T and E
Tvect = linspace(Tmin,Tmax,ETgrid);
Evect = linspace(Emin,Emax,ETgrid) .* 1e-4; % fix cm/yr

% catch for negative longitudes before Rc interpolation
if long < 0; long = long + 360; end;

% Age Relative to t0=2010 - LSD tv from LSDfix
% tv = [0:10:50 60:100:50060 51060:1000:2000060 logspace(log10(2001060),7,200)];

% Fix w,Rc,SPhi, for sp and mu prod rate scaling
LSDfix = LSD_fix(lat,long,Tmax+2010-samplingyr,-1,consts);

% time vector tv1
tv1 = LSDfix.tv;

% adjust tv, Rc, and SPhi to sampling year
if samplingyr <= 2010;
	clipidx = min(find(tv1 > 2010-samplingyr));
	tv = [2010-samplingyr tv1(clipidx:end)];
	Rc = interp1(tv1,LSDfix.Rc,tv);
	SPhi = interp1(tv1,LSDfix.SPhi,tv);
	tv = tv - 2010 + samplingyr;
else; % assume 2010 value for all years >2010
	Rc = [LSDfix.Rc(1) LSDfix.Rc];
	SPhi = [LSDfix.SPhi(1) LSDfix.SPhi];
	tv = [0 (tv1 + samplingyr - 2010)];
end;

% calculate min and max depth (cm) and make shielding depth vector
mind = min(dv);
maxd = max(dv) + Tmax.*Emax.*1e-4;
dz = linspace(mind,maxd,100);

% muon production
P_mu = P_mu_LSD(dz.*rho,atm,LSDfix.RcEst,consts.SPhiInf,nucl10,nucl26,consts,'no');

% pick out Pmu if data exists
if nucl10 == 1; Pmu10 = P_mu.Be .* shield; end;
if nucl26 == 1; Pmu26 = P_mu.Al .* shield; end;

% spallation surface production scaling
Psp0 = LSDspal(atm,Rc,SPhi,LSDfix.w,nucl10,nucl26,consts);

% pick out Psp if data exists
if nucl10 == 1; Psp010 = Psp0.Be .* shield; end;
if nucl26 == 1; Psp026 = Psp0.Al .* shield; end;

% interpolate Lsp using CRONUScalc method (Sato 2008; Marrero et al. 2016)
Lsp = rawattenuationlength(atm,Rc);

% loop for Tvect
for i = 1:numel(Tvect);
	% clear screen and display i
	clc;
	fprintf(1,'Iterating up to i = %.0f (number of E and T points)\n',ETgrid)
	i
	
	% fix tv2 and Lsp2
	clipidx = max(find(tv < Tvect(i)));
	tv2 = [tv(1:clipidx) Tvect(i)];
	Lsp2 = interp1(tv,Lsp,tv2);
	
	if nucl10 == 1;
		% interpolate Psp0 over time
		Psp010T = interp1(tv,Psp010,tv2);
	end;
	if nucl26 == 1;
		% interpolate Psp0 over time
		Psp026T = interp1(tv,Psp026,tv2);
	end;
	
	% fix depth matrix for tv2 and all E in Evect
	depthmT = bsxfun(@times,tv2,Evect');
	
	% loop for individual samples
	for j = 1:numel(dv)
		% add depth of sample
		depthm = depthmT + dv(j);
		
		if N10(j)+delN10(j) > 0;
			% interpolate Pmu over time for all E
			Pmu10m = interp1(dz',Pmu10',depthm','pchip');
			
			% calculate Psp over time for all E
			Psp10m = repmat(Psp010T.*Pref10,numel(Evect),1)' .* exp(-rho.*depthm./repmat(Lsp2,numel(Evect),1))';
			
			% decay matrix
			dcf10m = repmat(exp(-tv2.*l10),numel(Evect),1)';
			
			% calculate N for all E
			N10T = trapz(tv2',Psp10m.*dcf10m + Pmu10m.*dcf10m);
			
			% calculate N diff for all E
			N10diff(j,:) = ((N10(j)-N10T) ./ delN10(j)).^2;
		end;
		
		if N26(j)+delN26(j) > 0;
			% interpolate Pmu over time for all E
			Pmu26m = interp1(dz',Pmu26',depthm','pchip');
			
			% calculate Psp over time for all E
			Psp26m = repmat(Psp026T.*Pref26,numel(Evect),1)' .* exp(-rho.*depthm./repmat(Lsp2,numel(Evect),1))';
			
			% decay matrix
			dcf26m = repmat(exp(-tv2.*l26),numel(Evect),1)';
			
			% calculate N for all E
			N26T = trapz(tv2',Psp26m.*dcf26m + Pmu26m.*dcf26m);
			
			% calculate N diff for all E
			N26diff(j,:) = (N26(j)-N26T).^2 ./ delN26(j).^2;
		end;
	end;
	
	% calculate Rchi2 for all E and clear Ndiff
	if nucl10 == 1;
		Rchi2m10(i,:) = sum(N10diff) ./ (n10-1);
		clear N10diff;
	end;
	if nucl26 == 1;
		Rchi2m26(i,:) = sum(N26diff) ./ (n26-1);
		clear N26diff;
	end;
end;

% fix mm/ka
Evect = Evect .* 1e4;

fprintf(1,'T-range: %.0f - %.0f yr\n',Tmin,Tmax)
fprintf(1,'E-range: %.1f - %.1f mm/ka\n',Emin,Emax)

% contour line reduced chi-square values to add to minimum reduced chi-square value
cl = [0.05 0.5 1 2];

% if 10Be exists
if nucl10 == 1;
	% interpolate to finer mesh with spline
	Rchi2m10i = interp2(Evect,Tvect,Rchi2m10,xx,yy,'spline');
	
	% find index and minimum chi square
	[idx10T,idx10E] = find(Rchi2m10i == min(min(Rchi2m10i)));
	Tbest10 = yy(idx10T);
	Ebest10 = xx(idx10E);
	Rchisq10 = Rchi2m10i(idx10T,idx10E);
	Pvalue10 = 1 - chi2cdf(Rchisq10.*(n10-1),n10-1);
	
	% contour lines - display lines for Rchisq plus values in vector cl
	cl10 = cl + Rchisq10;
	
	% plotting---------------------------------	
	figure(1);
	hold on;
	
	plot(Ebest10,Tbest10,'.0','markersize',8);
	contour(xx,yy,Rchi2m10i,cl10);
	axis([Emin Emax Tmin Tmax],'square');
	xlabel('10Be erosion (mm/ka)');
	ylabel('10Be exposure duration (yr)');
	
	hold off;
	% end plotting-----------------------------
	
	fprintf(1,'10Be   E = %.1f mm/ka   T = %.0f yr   Rchi2 = %.2f   P-value = %.2f\n',Ebest10,Tbest10,Rchisq10,Pvalue10)
end;

% if 26Al exists
if nucl26 == 1;
	% interpolate to finer mesh with spline
	Rchi2m26i = interp2(Evect,Tvect,Rchi2m26,xx,yy,'spline');
	
	% find index and minimum chi square
	[idx26T,idx26E] = find(Rchi2m26i == min(min(Rchi2m26i)));
	Tbest26 = yy(idx26T);
	Ebest26 = xx(idx26E);
	Rchisq26 = Rchi2m26i(idx26T,idx26E);
	Pvalue26 = 1 - chi2cdf(Rchisq26.*(n26-1),n26-1);
	
	% contour lines - display lines for Rchisq plus values in vector cl
	cl26 = cl + Rchisq26;
	
	% plotting---------------------------------	
	figure(2);
	hold on;
	
	plot(Ebest26,Tbest26,'.0','markersize',8);
	contour(xx,yy,Rchi2m26i,cl26);
	axis([Emin Emax Tmin Tmax],'square');
	xlabel('26Al erosion (mm/ka)');
	ylabel('26Al exposure duration (yr)');
	
	hold off;
	% end plotting-----------------------------
	
	fprintf(1,'26Al   E = %.1f mm/ka   T = %.0f yr   Rchi2 = %.2f   P-value = %.2f\n',Ebest26,Tbest26,Rchisq26,Pvalue26)
end;

toc()
