% Script for 10Be and 26Al reference production rate calibration.
% Calibrate site reference 10Be and/or 26Al production rate using chi-square minimization.
% Jakob Heyman - 2016-2017

clear all;

tic();

% What version is this?
ver = '201702';

% min and max Pref
Pmin10 = 3;
Pmax10 = 5;
Pmin26 = 20;
Pmax26 = 40;

% read and fix input file
[samplein.sample_name,samplein.lat,samplein.long,samplein.elv,samplein.aa,samplein.thick,samplein.rho,samplein.othercorr,samplein.E,samplein.N10,samplein.delN10,samplein.be_stds,samplein.N26,samplein.delN26,samplein.al_stds,samplein.samplingyr,samplein.truet,samplein.deltruet] = textread('input.txt','%s %n %n %n %s %n %n %n %n %n %n %s %n %n %s %n %n %n');

samplein.sample_name = strvcat(samplein.sample_name);
samplein.aa = strvcat(samplein.aa);
samplein.be_stds = strvcat(samplein.be_stds);
samplein.al_stds = strvcat(samplein.al_stds);

% run and load constants
make_al_be_consts;
load al_be_consts;

consts = al_be_consts;

% make consts_LSD
make_consts_LSD;
load consts_LSD;

% convert 10Be concentrations according to standards
for i = 1:numel(samplein.N10);
	be_mult(i,1) = al_be_consts.be_stds_cfs(strmatch(samplein.be_stds(i,:),al_be_consts.be_stds_names,'exact'));
end;
samplein.N10 = samplein.N10 .* be_mult;
samplein.delN10 = samplein.delN10 .* be_mult;

% convert 26Al concentrations according to standards
for i = 1:numel(samplein.N26);
	al_mult(i,1) = al_be_consts.al_stds_cfs(strmatch(samplein.al_stds(i,:),al_be_consts.al_stds_names,'exact'));
end;
samplein.N26 = samplein.N26 .* al_mult;
samplein.delN26 = samplein.delN26 .* al_mult;

% Pref for simple age estimates
P_ref_nu10 = al_be_consts.P10_ref_nu; delP_ref_nu10 = al_be_consts.delP10_ref_nu;
P_ref_nu26 = al_be_consts.P26_ref_nu; delP_ref_nu26 = al_be_consts.delP26_ref_nu;

% Be-10 and Al-26 decay constants and spallation attenuation approximation
l10 = al_be_consts.l10;
l26 = al_be_consts.l26;
Lsp1 = al_be_consts.Lsp;

% make Pref vectors
Pvect10 = [Pmin10:0.01:Pmax10];
Pvect26 = [Pmin26:0.02:Pmax26];

% declare age and unc matrixes
age_nu10 = []; unc_nu10 = [];
age_nu26 = []; unc_nu26 = [];
calage = []; calunc = [];

Nsample10 = 0;
Nsample26 = 0;

% pick out samples one by one
for i = 1:numel(samplein.lat);	
	sample.sample_name = samplein.sample_name(i,:);
	sample.lat = samplein.lat(i);
	sample.long = samplein.long(i);
	sample.elv = samplein.elv(i);
	sample.aa = samplein.aa(i,:);
	sample.thick = samplein.thick(i);
	sample.rho = samplein.rho(i);
	sample.othercorr = samplein.othercorr(i);
	sample.E = samplein.E(i);
	sample.N10 = samplein.N10(i);
	sample.delN10 = samplein.delN10(i);
	sample.be_stds = samplein.be_stds(i,:);
	sample.N26 = samplein.N26(i);
	sample.delN26 = samplein.delN26(i);
	sample.al_stds = samplein.al_stds(i,:);
	sample.samplingyr = samplein.samplingyr(i,:);
	sample.truet = samplein.truet(i);
	sample.deltruet = samplein.deltruet(i);
	
	if sample.N10 + sample.delN10 + sample.N26 + sample.delN26 > 0;
		fprintf(1,'%.0f. %s',i,num2str(sample.sample_name))
		
		% define sample site atmospheric pressure
		if (strcmp(sample.aa,'std'));
			sample.pressure = ERA40atm(sample.lat,sample.long,sample.elv);
		elseif (strcmp(sample.aa,'ant'));
			sample.pressure = antatm(sample.elv);
		elseif (strcmp(sample.aa,'pre'));
			sample.pressure = sample.elv;
		end;
		
		% Atoms/g measurement
		N10 = sample.N10; delN10 = sample.delN10;
		N26 = sample.N26; delN26 = sample.delN26;
		
		% Initial thickness scaling factor for simple age calculation
		if sample.thick > 0;
			thickSF = thickness(sample.thick,Lsp1,sample.rho);
		else
			thickSF = 1;
		end;
		
		% Find P scaling factor according to Stone/Lal
		P_St_SF = stone2000(sample.lat,sample.pressure,1) * thickSF * sample.othercorr;
		
		% Set nucl and mt to 0 for both 10/26
		nucl10 = 0; nucl26 = 0; mt10 = 0; mt26 = 0;
		
		% if 10Be measured: calculate max time
		if (N10 + delN10) > 0;
			nucl10 = 1;
			Nsample10 = Nsample10 + 1;
			
			% Find P according to Stone/Lal
			% no muon production here!
			% P_ref_nu used as ref prod rate
			P_St10 = P_ref_nu10 * P_St_SF;
			A10 = l10 + sample.rho * sample.E ./Lsp1;
			
			if (sample.N10 >= (P_St10./A10));
				% if appears to be saturated in simple-age-world, simple age equation
				% would evaluate to NaN. Avoid this.
				% set results to -1; this flags it
				t_simple10 = -1;
			else;
				% Actually do calculation if possible
				t_simple10 = (-1/A10)*log(1-(sample.N10 * A10 / P_St10));
			end;
			
			% max time (mt10) for 10Be in LSDfix
			mt10 = t_simple10 .* 2;
			
			% clip to limit computations...
			if mt10 < 0; % Saturated WRT simple age - use full tv
				mt10 = 1e7;
			elseif  mt10 < 12060;
				mt10 = 12060; % Don't allow unreasonably short times
			elseif mt10 > 1e7;
				mt10 = 1e7;
			end;
		end;
		
		% if 26Al measured: calculate max time
		if (N26 + delN26) > 0;
			nucl26 = 1;
			Nsample26 = Nsample26 + 1;
			
			% Find P according to Stone/Lal
			% no muon production here!
			% P_ref_nu used as ref prod rate
			P_St26 = P_ref_nu26 * P_St_SF;
			A26 = l26 + sample.rho * sample.E ./Lsp1;

			if (sample.N26 >= (P_St26./A26));
				% if appears to be saturated in simple-age-world, simple age equation
				% would evaluate to NaN. Avoid this.
				% set results to -1; this flags it
				t_simple26 = -1;
			else;
				% Actually do calculation if possible
				t_simple26 = (-1/A26)*log(1-(sample.N26 * A26 / P_St26));
			end;
			
			% max time (mt26) for 26Al in LSDfix
			mt26 = t_simple26 .* 2;
			
			% clip to limit computations...
			if mt26 < 0; % Saturated WRT simple age - use full tv
				mt26 = 1e7;
			elseif  mt26 < 12060;
				mt26 = 12060; % Don't allow unreasonably short times
			elseif mt26 > 1e7;
				mt26 = 1e7;
			end;
		end;
		
		% pick largest of mt10 and mt26 as max time
		mt = max(mt10,mt26);
		
		% catch for negative longitudes before Rc interpolation
		if sample.long < 0; sample.long = sample.long + 360;end;
		
		% Age Relative to t0=2010 - LSD tv from LSDfix
		% tv = [0:10:50 60:100:50060 51060:1000:2000060 logspace(log10(2001060),7,200)];
		
		% Fix w,Rc,SPhi, for sp and nu prod rate scaling
		LSDfix = LSD_fix(sample.lat,sample.long,mt,-1,consts);
		
		% time vector tv1
		tv1 = LSDfix.tv;
		
		% adjust tv, Rc, and SPhi to sampling year
		if sample.samplingyr <= 2010;
			clipidx = min(find(tv1 > 2010-sample.samplingyr));
			tv = [2010-sample.samplingyr tv1(clipidx:end)];
			Rc = interp1(tv1,LSDfix.Rc,tv);
			SPhi = interp1(tv1,LSDfix.SPhi,tv);
			tv = tv - 2010 + sample.samplingyr;
		else; % assume 2010 value for all years >2010
			Rc = [LSDfix.Rc(1) LSDfix.Rc];
			SPhi = [LSDfix.SPhi(1) LSDfix.SPhi];
			tv = [0 (tv1 + sample.samplingyr - 2010)];
		end;
		
		% Production from muons
		if sample.E <= 0;
			P_mu = P_mu_LSD(sample.thick.*sample.rho./2,sample.pressure,LSDfix.RcEst,consts.SPhiInf,nucl10,nucl26,consts,'no');
			if nucl10 == 1; sample.mu10 = P_mu.Be .* sample.othercorr; end;
			if nucl26 == 1; sample.mu26 = P_mu.Al .* sample.othercorr; end;
		else;
			tv_z = (tv.*sample.E + sample.thick./2) .* sample.rho; % time - depth vect (g/cm^2)
			if nucl10 == 1;
				aged10 = sample.E .* t_simple10; % depth at t simple
				maxd10 = sample.E .* mt10; % max depth
				mu_z10 = ([linspace(0,aged10,9) maxd10] + sample.thick./2) .* sample.rho; % d vect (g/cm^2)
				if mu_z10(end) < tv_z(end); mu_z10(end+1) = tv_z(end); end; % add value at end of mu_z if shorter than tv_z
				P_mu_d10 = P_mu_LSD(mu_z10,sample.pressure,LSDfix.RcEst,consts.SPhiInf,1,0,consts,'no'); % Pmu at d
				sample.mu10 = interp1(mu_z10,P_mu_d10.Be,tv_z,'pchip') .* sample.othercorr; % P_mu over time
			end;
			if nucl26 == 1;
				aged26 = sample.E .* t_simple26; % depth at t simple
				maxd26 = sample.E .* mt26; % max depth
				mu_z26 = ([linspace(0,aged26,9) maxd26] + sample.thick./2) .* sample.rho; % d vect (g/cm^2)
				if mu_z26(end) < tv_z(end); mu_z26(end+1) = tv_z(end); end; % add value at end of mu_z if shorter than tv_z
				P_mu_d26 = P_mu_LSD(mu_z26,sample.pressure,LSDfix.RcEst,consts.SPhiInf,0,1,consts,'no'); % Pmu at d
				sample.mu26 = interp1(mu_z26,P_mu_d26.Al,tv_z,'pchip') .* sample.othercorr; % P_mu over time
			end;
		end;
		
		% sp and nu spallation production scaling
		%LSDsp = LSDspal(sample.pressure,LSDfix.Rc,LSDfix.SPhi,LSDfix.w,nucl10,nucl26);
		LSDnu = LSDspal(sample.pressure,Rc,SPhi,LSDfix.w,nucl10,nucl26,consts);
		
		% interpolate Lsp using CRONUScalc method (Sato 2008; Marrero et al. 2016)
		Lsp = rawattenuationlength(sample.pressure,Rc);
		
		% Thickness scaling factor.
		if sample.thick > 0;
			thickSF = thickness(sample.thick,Lsp,sample.rho);
		else
			thickSF = 1;
		end;
		
		% For decay erosion
		dpfs = exp(-tv.*sample.E.*sample.rho./Lsp); % spallation depth dependence
		
		if nucl10 == 1;
			% For decay
			dcf10 = exp(-tv.*l10); % decay factor;
			
			% sample prod rate matrix including decay and erosion (each col = one Pref)
			P_nu10lm = bsxfun(@times,LSDnu.Be'.*dcf10'.*dpfs'.*thickSF'.*sample.othercorr,Pvect10);
			P_full10lm = bsxfun(@plus,P_nu10lm,sample.mu10'.*dcf10');
			
			% Calculate N(t) including decay and erosion
			N_nu10 = cumtrapz(tv',P_full10lm);
			
			% test for saturation and calculate ages
			if N10 > min(max(N_nu10));
				[test,idx] = find(N10 > N_nu10(end,:));
				fprintf(1,'Sample %s saturated for Pref10 < %.2f\n',sample.sample_name,Pvect10(max(idx)));
			else;
				for j = 1:numel(Pvect10);
					t_nu10(j) = interp1(N_nu10(:,j),tv',N10);
				end;
			end;
			
			% Error propagation from Balco et al. (2008) CRONUS calculator
			% A with integrated average Lsp
			Lsp_avg = interp1(tv,cumtrapz(tv,Lsp),t_nu10)./t_nu10;
			A = l10 + sample.rho .* sample.E ./Lsp_avg;
			
			% extract t, Pref, delPref for SF
			tt = t_nu10;
			if min(tt) > 0; % Not saturated, is an age
				% do most of computation
				FP = (N10.*A)./(1 - exp(-A.*tt));
				dtdN = 1./(FP - N10.*A);
				% make respective delt's
				delt_nu10 = sqrt(dtdN.^2 .* delN10.^2);
			else; % set unc to 1
				delt_nu10 = (tt == 0);
				[test,idx] = find(tt > 0);
				% do most of computation
				FP = (N10.*A(idx))./(1 - exp(-A(idx).*tt(idx)));
				dtdN = 1./(FP - N10.*A(idx));
				% make respective delt's
				delt_nu10(idx) = sqrt(dtdN.^2 .* delN10(idx).^2);
			end;
			
			% fill age and unc matrix
			age_nu10(Nsample10,:) = t_nu10;
			unc_nu10(Nsample10,:) = delt_nu10;
			
			% fill calage and calunc matrix
			calage10(Nsample10,:) = repmat(sample.truet,[1,numel(Pvect10)]);
			calunc10(Nsample10,:) = repmat(sample.deltruet,[1,numel(Pvect10)]);
			
			% find individual sample Pref and Pref uncertainty including calage uncertainty
			Pref_sample_nu10(Nsample10) = interp1(age_nu10(Nsample10,:)-calage10(Nsample10,:),Pvect10,0,'pchip');
			Pref_sampleunc_nu10(Nsample10) = sqrt((interp1(Pvect10,unc_nu10(Nsample10,:),Pref_sample_nu10(Nsample10)) / calage10(Nsample10,1) * Pref_sample_nu10(Nsample10))^2 + (calunc10(Nsample10,1)/calage10(Nsample10,1) * Pref_sample_nu10(Nsample10))^2);
			
			% pick out individual sample P-ref and unc
			output10(i,1) = Pref_sample_nu10(Nsample10);
			output10(i,2) = Pref_sampleunc_nu10(Nsample10);
			
			fprintf(1,'    Pref10 = %.3f ± %.3f at/g/yr',output10(i,1),output10(i,2))
		end;
		
		if nucl26 == 1;
			% For decay
			dcf26 = exp(-tv.*l26); % decay factor;
			
			% sample prod rate matrix including decay and erosion (each col = one Pref)
			P_nu26lm = bsxfun(@times,LSDnu.Al'.*dcf26'.*dpfs'.*thickSF'.*sample.othercorr,Pvect26);
			P_full26lm = bsxfun(@plus,P_nu26lm,sample.mu26'.*dcf26');
			
			% Calculate N(t) including decay and erosion
			N_nu26 = cumtrapz(tv',P_full26lm);
			
			% test for saturation and calculate ages
			if N26 > min(max(N_nu26));
				[test,idx] = find(N26 > N_nu26(end,:));
				fprintf(1,'Sample %s saturated for Pref26 < %.2f\n',sample.sample_name,Pvect26(max(idx)));
			else;
				for j = 1:numel(Pvect26);
					t_nu26(j) = interp1(N_nu26(:,j),tv',N26);
				end;
			end;
			
			% Error propagation from Balco et al. (2008) CRONUS calculator
			% A with integrated average Lsp
			Lsp_avg = interp1(tv,cumtrapz(tv,Lsp),t_nu26)./t_nu26;
			A = l26 + sample.rho .* sample.E ./Lsp_avg;
			
			% extract t, Pref, delPref for SF
			tt = t_nu26;
			if min(tt) > 0; % Not saturated, is an age
				% do most of computation
				FP = (N26.*A)./(1 - exp(-A.*tt));
				dtdN = 1./(FP - N26.*A);
				% make respective delt's
				delt_nu26 = sqrt(dtdN.^2 .* delN26.^2);
			else; % set unc to 1
				delt_nu26 = (tt == 0);
				[test,idx] = find(tt > 0);
				% do most of computation
				FP = (N26.*A(idx))./(1 - exp(-A(idx).*tt(idx)));
				dtdN = 1./(FP - N26.*A(idx));
				% make respective delt's
				delt_nu26(idx) = sqrt(dtdN.^2 .* delN26(idx).^2);
			end;
			
			% fill age and unc matrix
			age_nu26(Nsample26,:) = t_nu26;
			unc_nu26(Nsample26,:) = delt_nu26;
			
			% fill calage and calunc matrix
			calage26(Nsample26,:) = repmat(sample.truet,[1,numel(Pvect26)]);
			calunc26(Nsample26,:) = repmat(sample.deltruet,[1,numel(Pvect26)]);
			
			% find individual sample Pref and Pref uncertainty including calage uncertainty
			Pref_sample_nu26(Nsample26) = interp1(age_nu26(Nsample26,:)-calage26(Nsample26,:),Pvect26,0,'pchip');
			Pref_sampleunc_nu26(Nsample26) = sqrt((interp1(Pvect26,unc_nu26(Nsample26,:),Pref_sample_nu26(Nsample26)) / calage26(Nsample26,1) * Pref_sample_nu26(Nsample26))^2 + (calunc26(Nsample26,1)/calage26(Nsample26,1) * Pref_sample_nu26(Nsample26))^2);
			
			% pick out individual sample P-ref and unc
			output26(i,1) = Pref_sample_nu26(Nsample26);
			output26(i,2) = Pref_sampleunc_nu26(Nsample26);
			
			fprintf(1,'    Pref26 = %.3f ± %.3f at/g/yr',output26(i,1),output26(i,2))
		end;
		fprintf(1,'\n')
	end;
	
	clear sample;
end;

if Nsample10 > 0;
	if numel(output10(:,1))<numel(samplein.N10);
		output10(numel(samplein.N10),2) = 0;
	end;
end;

if Nsample10 > 1;
	% calculate weighted ages for ages minus calage
	agetest_nu10 = sum((age_nu10 - calage10)./unc_nu10.^2)./sum(1./unc_nu10.^2);
	
	% pick out Pref
	Pref_nu10 = interp1(agetest_nu10,Pvect10,0,'pchip');
	
	% find individual sample age for Pref
	ageP_sample_nu10 = interp1(Pvect10',age_nu10',Pref_nu10,'pchip');
	
	% find individual sample age unc for Pref
	uncP_sample_nu10 = interp1(Pvect10',unc_nu10',Pref_nu10,'pchip');
	
	% pick out exact chi square
	chisq_nu10 = 1/(Nsample10-1) .* sum(((ageP_sample_nu10 - calage10(:,1)')./uncP_sample_nu10).^2);
	
	% calculate P value
	Pvalue10 = 1 - chi2cdf(chisq_nu10.*(Nsample10-1),Nsample10-1);
	
	% calculate reduced chi square for full Pvect
	chi_nu10 = 1/(Nsample10-1) .* sum(((age_nu10 - calage10)./unc_nu10).^2);
	
	% find minimum chi square and index
	[chimin_nu10,idx_nu10] = min(chi_nu10);
	
	% find low and high point of Pref based on chi square + 1
	low_nu10 = interp1(chi_nu10(1:idx_nu10),Pvect10(1:idx_nu10),chisq_nu10+1,'pchip');
	high_nu10 = interp1(chi_nu10(idx_nu10:end),Pvect10(idx_nu10:end),chisq_nu10+1,'pchip');
	
	% calculate reference prod rate uncertainty (not including calib age unc) from low and high Pref values
	delP1_nu10 = (high_nu10-low_nu10)/2;
	
	% calculate calib age unc part
	calage_unc10 = mean(calunc10(:,1)./calage10(:,1));
	
	% calculate total prod rate uncertainty
	delP_nu10 = sqrt(delP1_nu10^2 + (calage_unc10 * Pref_nu10)^2);
	
	% plot probdens graphs --------------------------------------------------------------
	figure(1);
	hold on;
	Pmin2 = Pmin10 - 0.5;
	Pmax2 = Pmax10 + 0.5;
	steg = 0.01;
	
	medel = Pref_sample_nu10';
	stdav = sqrt(Pref_sampleunc_nu10'.^2 - (calunc10(:,1)./calage10(:,1).* medel).^2);
	
	Pvect2 = linspace(Pmin2, Pmax2, (Pmax2-Pmin2)/steg+1);
	
	tidm = repmat(Pvect2, numel(medel), 1);
	medelm = repmat(medel, 1, numel(Pvect2));
	stdavm = repmat(stdav, 1, numel(Pvect2));
	
	probdensmatr = normpdf(tidm, medelm, stdavm);
	
	for k = 1:Nsample10;
		plot(Pvect2',probdensmatr(k,:)','r');
	end
	
	plot(Pvect2',sum(probdensmatr)','k');
	
	% plot Pref and unc
	ppmax = max(sum(probdensmatr))/8;
	plot([Pref_nu10-delP_nu10,Pref_nu10-delP_nu10],[0,ppmax],'b');
	plot([Pref_nu10,Pref_nu10],[0,ppmax],'b');
	plot([Pref_nu10+delP_nu10,Pref_nu10+delP_nu10],[0,ppmax],'b');
	
	axis('tic[x]','label[x]');
	xlabel('Pref 10Be (at/g/yr)');
	ylabel('Relative probability');
	
	hold off;
	% end plotting ----------------------------------------------------------------------
	
	% pick out full dataset P-ref, unc, and chisquare
	output10(end+1,1) = Pref_nu10;
	output10(end,2) = delP_nu10;
	output10(end+1,1) = chisq_nu10;
	output10(end,2) = Pvalue10;
	
	fprintf(1,'Pref10 = %.3f ± %.3f at/g/yr    R-chisq = %.3f    P-value = %.3f\n',Pref_nu10,delP_nu10,chisq_nu10,Pvalue10)
end;

if Nsample10 > 0;	
	% set 0 values to NaN
	nanmatr = output10>0;
	output10 = output10.*nanmatr./nanmatr;
	% print 10Be prodrates to prodrate10.txt
	out10 = fopen('prodrate10.txt','w');
	dlmwrite('prodrate10.txt',output10,'delimiter','\t','precision','%.3f');
	fclose(out10);
end;

if Nsample26 > 0;
	if numel(output26(:,1))<numel(samplein.N26);
		output26(numel(samplein.N26),2) = 0;
	end;
end;

if Nsample26 > 1;
	% calculate weighted ages for ages minus calage
	agetest_nu26 = sum((age_nu26 - calage26)./unc_nu26.^2)./sum(1./unc_nu26.^2);
	
	% pick out Pref
	Pref_nu26 = interp1(agetest_nu26,Pvect26,0,'pchip');
	
	% find individual sample age for Pref
	ageP_sample_nu26 = interp1(Pvect26',age_nu26',Pref_nu26,'pchip');
	
	% find individual sample age unc for Pref
	uncP_sample_nu26 = interp1(Pvect26',unc_nu26',Pref_nu26,'pchip');
	
	% pick out exact chi square
	chisq_nu26 = 1/(Nsample26-1) .* sum(((ageP_sample_nu26 - calage26(:,1)')./uncP_sample_nu26).^2);
	
	% calculate P value
	Pvalue26 = 1 - chi2cdf(chisq_nu26.*(Nsample26-1),Nsample26-1);
	
	% calculate reduced chi square for full Pvect
	chi_nu26 = 1/(Nsample26-1) .* sum(((age_nu26 - calage26)./unc_nu26).^2);
	
	% find minimum chi square and index
	[chimin_nu26,idx_nu26] = min(chi_nu26);
	
	% find low and high point of Pref based on chi square + 1
	low_nu26 = interp1(chi_nu26(1:idx_nu26),Pvect26(1:idx_nu26),chisq_nu26+1,'pchip');
	high_nu26 = interp1(chi_nu26(idx_nu26:end),Pvect26(idx_nu26:end),chisq_nu26+1,'pchip');
	
	% calculate reference prod rate uncertainty (not including calib age unc) from low and high Pref values
	delP1_nu26 = (high_nu26-low_nu26)/2;
	
	% calculate calib age unc part
	calage_unc26 = mean(calunc26(:,1)./calage26(:,1));
	
	% calculate total prod rate uncertainty
	delP_nu26 = sqrt(delP1_nu26^2 + (calage_unc26 * Pref_nu26)^2);
	
	% plot probdens graphs --------------------------------------------------------------
	figure(2);
	hold on;
	Pmin2 = Pmin26 - 0.5;
	Pmax2 = Pmax26 + 0.5;
	steg = 0.01;
	
	medel = Pref_sample_nu26';
	stdav = sqrt(Pref_sampleunc_nu26'.^2 - (calunc26(:,1)./calage26(:,1).* medel).^2);
	
	Pvect2 = linspace(Pmin2, Pmax2, (Pmax2-Pmin2)/steg+1);
	
	tidm = repmat(Pvect2, numel(medel), 1);
	medelm = repmat(medel, 1, numel(Pvect2));
	stdavm = repmat(stdav, 1, numel(Pvect2));
	
	probdensmatr = normpdf(tidm, medelm, stdavm);
	
	for k = 1:Nsample26;
		plot(Pvect2',probdensmatr(k,:)','r');
	end
	
	plot(Pvect2',sum(probdensmatr)','k');
	
	% plot Pref and unc
	ppmax = max(sum(probdensmatr))/8;
	plot([Pref_nu26-delP_nu26,Pref_nu26-delP_nu26],[0,ppmax],'b');
	plot([Pref_nu26,Pref_nu26],[0,ppmax],'b');
	plot([Pref_nu26+delP_nu26,Pref_nu26+delP_nu26],[0,ppmax],'b');
	
	axis('tic[x]','label[x]');
	xlabel('Pref 26Al (at/g/yr)');
	ylabel('Relative probability');
	
	hold off;
	% end plotting ----------------------------------------------------------------------
	
	% pick out full dataset P-ref, unc, and chisquare
	output26(end+1,1) = Pref_nu26;
	output26(end,2) = delP_nu26;
	output26(end+1,1) = chisq_nu26;
	output26(end,2) = Pvalue26;
	
	fprintf(1,'Pref26 = %.3f ± %.3f at/g/yr    R-chisq = %.3f    P-value = %.3f\n',Pref_nu26,delP_nu26,chisq_nu26,Pvalue26)
end;

if Nsample26 > 0;
	% set 0 values to NaN
	nanmatr = output26>0;
	output26 = output26.*nanmatr./nanmatr;
	% print 26Al prodrates to prodrate26.txt
	out26 = fopen('prodrate26.txt','w');
	dlmwrite('prodrate26.txt',output26,'delimiter','\t','precision','%.3f');
	fclose(out26);
end;

toc()
